==> haskell-monad-journal-0.8.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-HJqQ1Yu2hsWAMkGXbkQpAk
key: monad-journal-0.8.1-HJqQ1Yu2hsWAMkGXbkQpAk
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: ca7dcb83e034b063624303cce2762b85
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-HJqQ1Yu2hsWAMkGXbkQpAk
depends:
    base-4.11.1.0 mtl-2.2.2 transformers-0.5.5.0
    monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq
    transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq=87bdbc4e9457b26289613d38f0adffd2
             transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon=3700d08e9c0fb7ac1d166d53bb66cbcb
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-FcrKZ0dx0QyDVn4s4Otg0F
key: monad-journal-0.8.1-FcrKZ0dx0QyDVn4s4Otg0F
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: edf2cefc6d59071819a6f619dcb26204
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-FcrKZ0dx0QyDVn4s4Otg0F
depends:
    base-4.11.1.0 mtl-2.2.2 transformers-0.5.5.0
    monad-control-1.0.2.3-9g3P3spoed4Dm5BxFgJ5pL
    transformers-base-0.4.5.2-8XRnUljar8BDHMt3cPCext
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             monad-control-1.0.2.3-9g3P3spoed4Dm5BxFgJ5pL=be90ff1eeedc2d64ec69a5fa4d235652
             transformers-base-0.4.5.2-8XRnUljar8BDHMt3cPCext=38bea391ee10b49a0c9be04e9f005244
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
